==> DateTime-Locale-1.34.tar.gz: DateTime-Locale-1.34/share/se-SE.pl <==
{
  am_pm_abbreviated => [
    "i.b.",
    "e.b.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "se-SE",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "vuos",
    "ma\N{U+014b}",
    "gask",
    "duor",
    "bear",
    "l\N{U+00e1}v",
    "sotn",
  ],
  day_format_narrow => [
    "V",
    "M",
    "G",
    "D",
    "B",
    "L",
    "S",
  ],
  day_format_wide => [
    "vuoss\N{U+00e1}rga",
    "ma\N{U+014b}\N{U+014b}eb\N{U+00e1}rga",
    "gaskavahkku",
    "duorasdat",
    "bearjadat",
    "l\N{U+00e1}vvardat",
    "sotnabeaivi",
  ],
  day_stand_alone_abbreviated => [
    "vuos",
    "ma\N{U+014b}",
    "gask",
    "duor",
    "bear",
    "l\N{U+00e1}v",
    "sotn",
  ],
  day_stand_alone_narrow => [
    "V",
    "M",
    "G",
    "D",
    "B",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "vuoss\N{U+00e1}rga",
    "ma\N{U+014b}\N{U+014b}eb\N{U+00e1}rga",
    "gaskavahkku",
    "duorasdat",
    "bearjadat",
    "l\N{U+00e1}vvardat",
    "sotnabeaivi",
  ],
  era_abbreviated => [
    "o.Kr.",
    "m.Kr.",
  ],
  era_narrow => [
    "o.Kr.",
    "m.Kr.",
  ],
  era_wide => [
    "ovdal Kristtusa",
    "ma\N{U+014b}\N{U+014b}el Kristtusa",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Northern Sami",
  month_format_abbreviated => [
    "o\N{U+0111}\N{U+0111}j",
    "guov",
    "njuk",
    "cuo",
    "mies",
    "geas",
    "suoi",
    "borg",
    "\N{U+010d}ak\N{U+010d}",
    "golg",
    "sk\N{U+00e1}b",
    "juov",
  ],
  month_format_narrow => [
    "O",
    "G",
    "N",
    "C",
    "M",
    "G",
    "S",
    "B",
    "\N{U+010c}",
    "G",
    "S",
    "J",
  ],
  month_format_wide => [
    "o\N{U+0111}\N{U+0111}ajagem\N{U+00e1}nnu",
    "guovvam\N{U+00e1}nnu",
    "njuk\N{U+010d}am\N{U+00e1}nnu",
    "cuo\N{U+014b}om\N{U+00e1}nnu",
    "miessem\N{U+00e1}nnu",
    "geassem\N{U+00e1}nnu",
    "suoidnem\N{U+00e1}nnu",
    "borgem\N{U+00e1}nnu",
    "\N{U+010d}ak\N{U+010d}am\N{U+00e1}nnu",
    "golggotm\N{U+00e1}nnu",
    "sk\N{U+00e1}bmam\N{U+00e1}nnu",
    "juovlam\N{U+00e1}nnu",
  ],
  month_stand_alone_abbreviated => [
    "o\N{U+0111}\N{U+0111}j",
    "guov",
    "njuk",
    "cuo",
    "mies",
    "geas",
    "suoi",
    "borg",
    "\N{U+010d}ak\N{U+010d}",
    "golg",
    "sk\N{U+00e1}b",
    "juov",
  ],
  month_stand_alone_narrow => [
    "O",
    "G",
    "N",
    "C",
    "M",
    "G",
    "S",
    "B",
    "\N{U+010c}",
    "G",
    "S",
    "J",
  ],
  month_stand_alone_wide => [
    "o\N{U+0111}\N{U+0111}ajagem\N{U+00e1}nnu",
    "guovvam\N{U+00e1}nnu",
    "njuk\N{U+010d}am\N{U+00e1}nnu",
    "cuo\N{U+014b}om\N{U+00e1}nnu",
    "miessem\N{U+00e1}nnu",
    "geassem\N{U+00e1}nnu",
    "suoidnem\N{U+00e1}nnu",
    "borgem\N{U+00e1}nnu",
    "\N{U+010d}ak\N{U+010d}am\N{U+00e1}nnu",
    "golggotm\N{U+00e1}nnu",
    "sk\N{U+00e1}bmam\N{U+00e1}nnu",
    "juovlam\N{U+00e1}nnu",
  ],
  name => "Northern Sami Sweden",
  native_language => "davvis\N{U+00e1}megiella",
  native_name => "davvis\N{U+00e1}megiella Ruo\N{U+0167}\N{U+0167}a",
  native_script => undef,
  native_territory => "Ruo\N{U+0167}\N{U+0167}a",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "Sweden",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.37.tar.gz: DateTime-Locale-1.37/share/se-SE.pl <==
{
  am_pm_abbreviated => [
    "i.b.",
    "e.b.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "se-SE",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "vuos",
    "ma\N{U+014b}",
    "gask",
    "duor",
    "bear",
    "l\N{U+00e1}v",
    "sotn",
  ],
  day_format_narrow => [
    "V",
    "M",
    "G",
    "D",
    "B",
    "L",
    "S",
  ],
  day_format_wide => [
    "vuoss\N{U+00e1}rga",
    "ma\N{U+014b}\N{U+014b}eb\N{U+00e1}rga",
    "gaskavahkku",
    "duorasdat",
    "bearjadat",
    "l\N{U+00e1}vvardat",
    "sotnabeaivi",
  ],
  day_stand_alone_abbreviated => [
    "vuos",
    "ma\N{U+014b}",
    "gask",
    "duor",
    "bear",
    "l\N{U+00e1}v",
    "sotn",
  ],
  day_stand_alone_narrow => [
    "V",
    "M",
    "G",
    "D",
    "B",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "vuoss\N{U+00e1}rga",
    "ma\N{U+014b}\N{U+014b}eb\N{U+00e1}rga",
    "gaskavahkku",
    "duorasdat",
    "bearjadat",
    "l\N{U+00e1}vvardat",
    "sotnabeaivi",
  ],
  era_abbreviated => [
    "o.Kr.",
    "m.Kr.",
  ],
  era_narrow => [
    "o.Kr.",
    "m.Kr.",
  ],
  era_wide => [
    "ovdal Kristtusa",
    "ma\N{U+014b}\N{U+014b}el Kristtusa",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Northern Sami",
  month_format_abbreviated => [
    "o\N{U+0111}\N{U+0111}j",
    "guov",
    "njuk",
    "cuo",
    "mies",
    "geas",
    "suoi",
    "borg",
    "\N{U+010d}ak\N{U+010d}",
    "golg",
    "sk\N{U+00e1}b",
    "juov",
  ],
  month_format_narrow => [
    "O",
    "G",
    "N",
    "C",
    "M",
    "G",
    "S",
    "B",
    "\N{U+010c}",
    "G",
    "S",
    "J",
  ],
  month_format_wide => [
    "o\N{U+0111}\N{U+0111}ajagem\N{U+00e1}nnu",
    "guovvam\N{U+00e1}nnu",
    "njuk\N{U+010d}am\N{U+00e1}nnu",
    "cuo\N{U+014b}om\N{U+00e1}nnu",
    "miessem\N{U+00e1}nnu",
    "geassem\N{U+00e1}nnu",
    "suoidnem\N{U+00e1}nnu",
    "borgem\N{U+00e1}nnu",
    "\N{U+010d}ak\N{U+010d}am\N{U+00e1}nnu",
    "golggotm\N{U+00e1}nnu",
    "sk\N{U+00e1}bmam\N{U+00e1}nnu",
    "juovlam\N{U+00e1}nnu",
  ],
  month_stand_alone_abbreviated => [
    "o\N{U+0111}\N{U+0111}j",
    "guov",
    "njuk",
    "cuo",
    "mies",
    "geas",
    "suoi",
    "borg",
    "\N{U+010d}ak\N{U+010d}",
    "golg",
    "sk\N{U+00e1}b",
    "juov",
  ],
  month_stand_alone_narrow => [
    "O",
    "G",
    "N",
    "C",
    "M",
    "G",
    "S",
    "B",
    "\N{U+010c}",
    "G",
    "S",
    "J",
  ],
  month_stand_alone_wide => [
    "o\N{U+0111}\N{U+0111}ajagem\N{U+00e1}nnu",
    "guovvam\N{U+00e1}nnu",
    "njuk\N{U+010d}am\N{U+00e1}nnu",
    "cuo\N{U+014b}om\N{U+00e1}nnu",
    "miessem\N{U+00e1}nnu",
    "geassem\N{U+00e1}nnu",
    "suoidnem\N{U+00e1}nnu",
    "borgem\N{U+00e1}nnu",
    "\N{U+010d}ak\N{U+010d}am\N{U+00e1}nnu",
    "golggotm\N{U+00e1}nnu",
    "sk\N{U+00e1}bmam\N{U+00e1}nnu",
    "juovlam\N{U+00e1}nnu",
  ],
  name => "Northern Sami Sweden",
  native_language => "davvis\N{U+00e1}megiella",
  native_name => "davvis\N{U+00e1}megiella Ruo\N{U+0167}\N{U+0167}a",
  native_script => undef,
  native_territory => "Ruo\N{U+0167}\N{U+0167}a",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "Sweden",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
